@@ -50,10 +50,10 @@ contourToFreq <- function(data, verbose=FALSE) {
         cat('SR: ', sr, ' Len: ', fftLen, ' Hop: ', fftHop, sep ='')
     }
     for(i in seq_along(data)) {
-        data[[i]]$freq <- data[[i]]$contour * sr / fftLen
-        data[[i]]$allFreq <- do.call(cbind, lapply(data[[i]]$sliceData, function(x) x$peakData)) * sr / fftLen
+        data[[i]]$freq <- data[[i]]$contour / fftLen * sr
+        data[[i]]$allFreq <- do.call(cbind, lapply(data[[i]]$sliceData, function(x) x$peakData)) / fftLen * sr
         data[[i]]$time <- sapply(data[[i]]$sliceData,
-                                 function(x) x$sliceNumber) * fftHop / sr
+                                 function(x) x$sliceNumber) / sr * fftHop
     }
     data
 }
@@ -87,15 +87,15 @@ getPamFft <- function(data, method=c('new', 'old')) {
             }
             
             hops <- diff(samplePairs$start) / diff(samplePairs$slice)
+            hops <- as.integer(hops)
             hops <- unique(hops)
             hops <- hops[is.finite(hops)]
             if(length(hops) > 1) {
-                hops <- as.integer(hops)
                 checkPow2 <- round(log2(hops)) == log2(hops)
                 if(!any(checkPow2)) {
                     fftHop <- hops[1]
                 } else {
-                    fftHop <- which(checkPow2)[1]
+                    fftHop <- hops[which(checkPow2)[1]]
                 }
             } else {
                 fftHop <- hops
